==> uoa-login-core-3.0.0-sources.jar: eu/dnetlib/authentication/security/OpenAIREAuthenticationSuccessHandler.java <==
package eu.dnetlib.authentication.security;

import com.google.gson.JsonParser;
import eu.dnetlib.authentication.configuration.Properties;
import eu.dnetlib.authentication.entities.User;
import eu.dnetlib.authentication.services.SecurityService;
import eu.dnetlib.authentication.services.UserInfoService;
import jakarta.servlet.http.Cookie;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.servlet.http.HttpSession;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.security.core.Authentication;
import org.springframework.security.web.authentication.AuthenticationSuccessHandler;
import org.springframework.session.FindByIndexNameSessionRepository;
import java.io.IOException;
import java.util.Base64;
import java.util.Date;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

@Configuration
public class OpenAIREAuthenticationSuccessHandler implements AuthenticationSuccessHandler {

    private static final Logger logger = LogManager.getLogger(OpenAIREAuthenticationSuccessHandler.class);
    private final Properties properties;
    private final UserInfoService service;

    @Autowired
    public OpenAIREAuthenticationSuccessHandler(Properties properties, UserInfoService service) {
        this.properties = properties;
        this.service = service;
    }

    @Override
    public void onAuthenticationSuccess(HttpServletRequest request, HttpServletResponse response, Authentication authentication)
            throws IOException {
        HttpSession session = request.getSession();
        String redirect = (String) session.getAttribute("redirect");
        User user = this.service.getUserInfo(request);
        session.setAttribute(FindByIndexNameSessionRepository.PRINCIPAL_NAME_INDEX_NAME, user.getSub());
        try {
            if(properties.getAccessToken() != null && !properties.getAccessToken().isEmpty()) {
                Cookie accessToken = new Cookie(properties.getAccessToken(), user.getAccessToken());
                String regex = "^([A-Za-z0-9-_=]+)\\.([A-Za-z0-9-_=]+)\\.?([A-Za-z0-9-_.+=]*)$";
                Matcher matcher = Pattern.compile(regex).matcher(user.getAccessToken());
                if (matcher.find()) {
                    long exp = new JsonParser().parse(new String(Base64.getDecoder().decode(matcher.group(2)))).getAsJsonObject().get("exp").getAsLong();
                    accessToken.setMaxAge((int) (exp - (new Date().getTime() / 1000)));
                } else {
                    accessToken.setMaxAge(3600);
                }
                accessToken.setPath("/");
                accessToken.setDomain(properties.getDomain());
                response.addCookie(accessToken);
            }
            if(redirect != null) {
                response.sendRedirect(redirect);
                session.removeAttribute("redirect");
            } else {
                response.sendRedirect(properties.getRedirect());
            }
        } catch (IOException e) {
            logger.error("IOException in redirection ", e);
            throw new IOException(e);
        }
    }
}

==> uoa-login-core-3.0.1-sources.jar: eu/dnetlib/authentication/security/OpenAIREAuthenticationSuccessHandler.java <==
package eu.dnetlib.authentication.security;

import com.google.gson.JsonParser;
import eu.dnetlib.authentication.configuration.Properties;
import eu.dnetlib.authentication.entities.User;
import eu.dnetlib.authentication.services.UserInfoService;
import eu.dnetlib.uoaauthorizationlibrary.authorization.configuration.SecurityProperties;
import jakarta.servlet.http.Cookie;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import jakarta.servlet.http.HttpSession;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Configuration;
import org.springframework.security.core.Authentication;
import org.springframework.security.web.authentication.AuthenticationSuccessHandler;

import java.io.IOException;
import java.util.Base64;
import java.util.Date;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

@Configuration
public class OpenAIREAuthenticationSuccessHandler implements AuthenticationSuccessHandler {

    private static final Logger logger = LogManager.getLogger(OpenAIREAuthenticationSuccessHandler.class);
    private final Properties properties;
    private final String domain;
    private final UserInfoService service;

    @Autowired
    public OpenAIREAuthenticationSuccessHandler(Properties properties, UserInfoService service,
                                                SecurityProperties securityProperties) {
        this.properties = properties;
        this.service = service;
        this.domain = securityProperties.getDomain();
    }

    @Override
    public void onAuthenticationSuccess(HttpServletRequest request, HttpServletResponse response, Authentication authentication)
            throws IOException {
        HttpSession session = request.getSession();
        String redirect = (String) session.getAttribute("redirect");
        User user = this.service.getUserInfo(request);
        try {
            if(properties.getAccessToken() != null && !properties.getAccessToken().isEmpty()) {
                Cookie accessToken = new Cookie(properties.getAccessToken(), user.getAccessToken());
                String regex = "^([A-Za-z0-9-_=]+)\\.([A-Za-z0-9-_=]+)\\.?([A-Za-z0-9-_.+=]*)$";
                Matcher matcher = Pattern.compile(regex).matcher(user.getAccessToken());
                if (matcher.find()) {
                    long exp = new JsonParser().parse(new String(Base64.getDecoder().decode(matcher.group(2)))).getAsJsonObject().get("exp").getAsLong();
                    accessToken.setMaxAge((int) (exp - (new Date().getTime() / 1000)));
                } else {
                    accessToken.setMaxAge(3600);
                }
                accessToken.setPath("/");
                accessToken.setDomain(domain);
                response.addCookie(accessToken);
            }
            if(redirect != null) {
                response.sendRedirect(redirect);
                session.removeAttribute("redirect");
            } else {
                response.sendRedirect(properties.getRedirect());
            }
        } catch (IOException e) {
            logger.error("IOException in redirection ", e);
            throw new IOException(e);
        }
    }
}
